
From: Garrett Kajmowicz <gkajmowi@tbaytel.net>

This patch allows a person to not require mounting a root device at startup.  
This works idealy for people trying to use the initramfs/sysfs as the only 
filesystem.

What happens is that when the root device is set to 0,0 mount_root is not 
called.



 init/do_mounts.c |    9 +++++++++
 1 files changed, 9 insertions(+)

diff -puN init/do_mounts.c~no-root-device-option init/do_mounts.c
--- 25/init/do_mounts.c~no-root-device-option	2003-08-25 01:05:22.000000000 -0700
+++ 25-akpm/init/do_mounts.c	2003-08-25 01:06:40.000000000 -0700
@@ -389,6 +389,15 @@ void __init prepare_namespace(void)
 	if (is_floppy && rd_doload && rd_load_disk(0))
 		ROOT_DEV = Root_RAM0;
 
+	/*
+	 * If root=0:0 is provided, the user wants to leave initramfs as the
+	 * root filesystem.
+	 */
+#ifndef CONFIG_ROOT_NFS
+	if (MAJOR(ROOT_DEV) == UNNAMED_MAJOR && MINOR(ROOT_DEV) == 0)
+		goto out;
+#endif
+
 	mount_root();
 out:
 	umount_devfs("/dev");

_
